# Generated by Django 2.2.5 on 2019-10-18 13:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mds', '0055_post_fill_compliance_saved_at'),
    ]

    operations = [
        migrations.AlterField(
            model_name='compliance',
            name='saved_at',
            field=models.DateTimeField(auto_now=True, db_index=True),
        ),
    ]
